Package 'meddra.read'

Title: Load and Use 'MedDRA' Data for Clinical Trials
Description: 'MedDRA' data is used for defining adverse events in clinical studies. You can load and merge the data for use in categorizing the adverse events using this package. The package requires the data licensed from 'MedDRA' <https://www.meddra.org/>.
Authors: Bill Denney [aut, cre] (ORCID: <https://orcid.org/0000-0002-5759-428X>)
Maintainer: Bill Denney <[email protected]>
License: MIT + file LICENSE
Version: 0.0.1.9000
Built: 2026-05-18 10:08:52 UTC
Source: https://github.com/humanpred/meddra.read

Help Index


Combine together all of the MedDRA terms into a single data.frame

Description

Combine together all of the MedDRA terms into a single data.frame

Usage

join_meddra(data)

Arguments

data

MedDRA source data from read_meddra()

Value

A data.frame with the "soc_code", "soc_name", "soc_abbrev", "hlgt_code", "hlgt_name", "hlt_code", "hlt_name", "pt_code", "pt_name", "pt_soc_code", "llt_code", "llt_name", and "llt_currency"

Examples

example_dir <- system.file("example_meddra", package = "meddra.read")
meddra_raw <- read_meddra(example_dir)
meddra_df <- join_meddra(meddra_raw)

Read MedDRA datasets from the source MedDRA datasets

Description

Read MedDRA datasets from the source MedDRA datasets

Usage

read_meddra(directory)

Arguments

directory

the directory containing the MedAscii and SeqAscii directories

Value

A list of data.frames for each file in the MedDRA source distribution

Examples

example_dir <- system.file("example_meddra", package = "meddra.read")
meddra_raw <- read_meddra(example_dir)