Welcome to ClientVPS Mirrors

Help for package meddra.read
Title: Load and Use 'MedDRA' Data for Clinical Trials
Version: 0.0.1
Description: 'MedDRA' data is used for defining adverse events in clinical studies. You can load and merge the data for use in categorizing the adverse events using this package. The package requires the data licensed from 'MedDRA' https://www.meddra.org/.
License: MIT + file LICENSE
Imports: dplyr
Suggests: spelling, testthat (≥ 3.0.0)
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: https://humanpred.github.io/meddra.read/
Language: en-US
NeedsCompilation: no
Packaged: 2025-03-25 16:28:07 UTC; bill
Author: Bill Denney ORCID iD [aut, cre]
Maintainer: Bill Denney <wdenney@humanpredictions.com>
Repository: CRAN
Date/Publication: 2025-03-26 10:40:13 UTC

Combine together all of the MedDRA terms into a single data.frame

Description

Combine together all of the MedDRA terms into a single data.frame

Usage

join_meddra(data)

Arguments

data

MedDRA source data from read_meddra()

Value

A data.frame with the "soc_code", "soc_name", "soc_abbrev", "hlgt_code", "hlgt_name", "hlt_code", "hlt_name", "pt_code", "pt_name", "pt_soc_code", "llt_code", "llt_name", and "llt_currency"

Examples

## Not run: 
meddra_raw <- read_meddra("/path/to/meddra/distribution")
meddra_df <- join_meddra(meddra_raw)

## End(Not run)

Read MedDRA datasets from the source MedDRA datasets

Description

Read MedDRA datasets from the source MedDRA datasets

Usage

read_meddra(directory)

Arguments

directory

the directory containing the MedAscii and SeqAscii directories

Value

A list of data.frames for each file in the MedDRA source distribution

Examples

## Not run: 
read_meddra("/path/to/meddra/distribution")

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.